@@ -1284,18 +1284,41 @@ gegl_resample_nearest (guchar              *dst,
              d[2] = s[*(ijj++) + 2];
            );
     break;
+    case 5:IMPL(
+             uint32_t* d32 = (void*) d;
+             const uint32_t* s32 = (void*) &s[*(ijj++)];
+             d32[0] = s32[0];
+             d[4] = s[4];
+           );
+    break;
     case 4:IMPL(
              uint32_t* d32 = (void*) d;
              const uint32_t* s32 = (void*) &s[*(ijj++)];
              d32[0] = s32[0];
            );
     break;
+    case 6:IMPL(
+             uint32_t* d32 = (void*) d;
+             const uint32_t* s32 = (void*) &s[*(ijj++)];
+             d32[0] = s32[0];
+             d[4] = s[4];
+             d[5] = s[5];
+           );
+    break;
     case 8:IMPL(
              uint64_t* d64 = (void*) d;
              const uint64_t* s64 = (void*) &s[*(ijj++)];
              d64[0] = s64[0];
            );
     break;
+    case 12:IMPL(
+             uint32_t* d32 = (void*) d;
+             const uint32_t* s32 = (void*) &s[*(ijj++)];
+             d32[0] = s32[0];
+             d32[1] = s32[1];
+             d32[2] = s32[2];
+           );
+    break;
     case 16:IMPL(
              uint64_t* d64 = (void*) d;
              const uint64_t* s64 = (void*) &s[*(ijj++)];
@@ -1335,7 +1358,7 @@ gegl_resample_nearest (guchar              *dst,
 #define BOXFILTER_FUNCNAME   gegl_resample_boxfilter_u8
 #define BOXFILTER_TYPE       guchar
 #define BOXFILTER_TEMP_TYPE  guchar
-#define BOXFILTER_ROUND(val) ((int)((val)+0.5))
+#define BOXFILTER_ROUND(val) ((int)((val)+0.5f))
 #include "gegl-algorithms-boxfilter.inc"
 #undef BOXFILTER_FUNCNAME
 #undef BOXFILTER_TYPE
@@ -1345,7 +1368,7 @@ gegl_resample_nearest (guchar              *dst,
 #define BOXFILTER_FUNCNAME   gegl_resample_boxfilter_u16
 #define BOXFILTER_TYPE       guint16
 #define BOXFILTER_TEMP_TYPE  guint16
-#define BOXFILTER_ROUND(val) ((int)((val)+0.5))
+#define BOXFILTER_ROUND(val) ((int)((val)+0.5f))
 #include "gegl-algorithms-boxfilter.inc"
 #undef BOXFILTER_FUNCNAME
 #undef BOXFILTER_TYPE
@@ -1362,7 +1385,7 @@ static inline guint32 _gegl_trunc_u32(guint64 value)
 #define BOXFILTER_FUNCNAME   gegl_resample_boxfilter_u32
 #define BOXFILTER_TYPE       guint32
 #define BOXFILTER_TEMP_TYPE  guint64
-#define BOXFILTER_ROUND(val) _gegl_trunc_u32((val)+0.5)
+#define BOXFILTER_ROUND(val) _gegl_trunc_u32((val)+0.5f)
 #include "gegl-algorithms-boxfilter.inc"
 #undef BOXFILTER_FUNCNAME
 #undef BOXFILTER_TEMP_TYPE
@@ -1438,7 +1461,7 @@ static inline guint32 _gegl_trunc_u32(guint64 value)
 
 #define BILINEAR_FUNCNAME   gegl_resample_bilinear_u8
 #define BILINEAR_TYPE       guchar
-#define BILINEAR_ROUND(val) ((int)((val)+0.5))
+#define BILINEAR_ROUND(val) ((int)((val)+0.5f))
 #include "gegl-algorithms-bilinear.inc"
 #undef BILINEAR_FUNCNAME
 #undef BILINEAR_TYPE
@@ -1446,7 +1469,7 @@ static inline guint32 _gegl_trunc_u32(guint64 value)
 
 #define BILINEAR_FUNCNAME   gegl_resample_bilinear_u16
 #define BILINEAR_TYPE       guint16
-#define BILINEAR_ROUND(val) ((int)((val)+0.5))
+#define BILINEAR_ROUND(val) ((int)((val)+0.5f))
 #include "gegl-algorithms-bilinear.inc"
 #undef BILINEAR_FUNCNAME
 #undef BILINEAR_TYPE
@@ -1454,7 +1477,7 @@ static inline guint32 _gegl_trunc_u32(guint64 value)
 
 #define BILINEAR_FUNCNAME   gegl_resample_bilinear_u32
 #define BILINEAR_TYPE       guint32
-#define BILINEAR_ROUND(val) ((int)((val)+0.5))
+#define BILINEAR_ROUND(val) _gegl_trunc_u32((val)+0.5f)
 #include "gegl-algorithms-bilinear.inc"
 #undef BILINEAR_FUNCNAME
 #undef BILINEAR_TYPE
